DataSourceScan

Trait DataSourceScan 

pub trait DataSourceScan: 'static + Send {
    // Required methods
    fn dtype(&self) -> &DType;
    fn remaining_splits_estimate(&self) -> Estimate<usize>;
    fn next_splits<'life0, 'async_trait>(
        &'life0 mut self,
        max_splits: usize,
    ) -> Pin<Box<dyn Future<Output = VortexResult<Vec<SplitRef>>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
A data source scan produces splits that can be executed to read data from the source.

Required Methods

fn dtype(&self) -> &DType

The returned dtype of the scan.

fn remaining_splits_estimate(&self) -> Estimate<usize>

An estimate of the remaining splits.

fn next_splits<'life0, 'async_trait>( &'life0 mut self, max_splits: usize, ) -> Pin<Box<dyn Future<Output = VortexResult<Vec<SplitRef>>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Returns the next batch of splits to be processed.

This should not return more than max_splits splits, but may return fewer.

Implementors