pub trait Split: 'static + Send {
// Required methods
fn as_any(&self) -> &dyn Any;
fn execute(self: Box<Self>) -> VortexResult<SendableArrayStream>;
fn row_count_estimate(&self) -> Estimate<u64>;
fn byte_size_estimate(&self) -> Estimate<u64>;
}Expand description
A split represents a unit of work that can be executed to produce a stream of arrays.
Required Methods
Sourcefn execute(self: Box<Self>) -> VortexResult<SendableArrayStream>
fn execute(self: Box<Self>) -> VortexResult<SendableArrayStream>
Executes the split.
Sourcefn row_count_estimate(&self) -> Estimate<u64>
fn row_count_estimate(&self) -> Estimate<u64>
Returns an estimate of the row count for this split.
Sourcefn byte_size_estimate(&self) -> Estimate<u64>
fn byte_size_estimate(&self) -> Estimate<u64>
Returns an estimate of the byte size for this split.