Module strict_sorted_buffer

Module strict_sorted_buffer 

Defines a Buffer wrapper whose values are known to be strictly sorted.

Structs

StrictSortedBuffer
A buffer whose values are known to be strictly sorted in ascending order.