pub struct ScanRequest {
pub projection: Expression,
pub filter: Option<Expression>,
pub row_range: Option<Range<u64>>,
pub selection: Selection,
pub partition_selection: Selection,
pub partition_range: Option<Range<u64>>,
pub ordered: bool,
pub limit: Option<u64>,
}Expand description
A request to scan a data source.
Fields
projection: ExpressionProjection expression. Defaults to root() which returns all columns.
filter: Option<Expression>Filter expression, None implies no filter.
row_range: Option<Range<u64>>The per-partition row range to read. Row range will be applied over every partition you scan.
selection: SelectionThe per-partition row selection to read. Row selection will be applied over every partition you scan.
partition_selection: SelectionPartition selection to scan, which allows readers to skip unwanted partitions.
partition_range: Option<Range<u64>>Partition range to scan, which allows readers to skip unwanted partitions.
ordered: boolWhether the scan should preserve row order. If false, the scan may produce rows in any order, for example to enable parallel execution across partitions.
limit: Option<u64>Optional limit on the number of rows returned by scan. Limits are applied after all filtering and row selection.