pub trait DataSourceScan: 'static + Send {
// Required methods
fn dtype(&self) -> &DType;
fn partition_count(&self) -> Precision<usize>;
fn partitions(self: Box<Self>) -> PartitionStream;
}Expand description
A data source scan produces partitions that can be executed to read data from the source.
Required Methods
Sourcefn partition_count(&self) -> Precision<usize>
fn partition_count(&self) -> Precision<usize>
Returns an estimate of the total number of partitions the scan will produce.
Sourcefn partitions(self: Box<Self>) -> PartitionStream
fn partitions(self: Box<Self>) -> PartitionStream
Returns a stream of partitions to be processed.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".