DataSourceScan

Trait DataSourceScan 

pub trait DataSourceScan: 'static + Send {
    // Required methods
    fn dtype(&self) -> &DType;
    fn partition_count(&self) -> Option<Precision<usize>>;
    fn partitions(self: Box<Self>) -> PartitionStream;
}
A data source scan produces partitions that can be executed to read data from the source.

Required Methods

fn dtype(&self) -> &DType

The returned dtype of the scan.

fn partition_count(&self) -> Option<Precision<usize>>

Returns an estimate of the total number of partitions the scan will produce.

fn partitions(self: Box<Self>) -> PartitionStream

Returns a stream of partitions to be processed.

Implementors