Split

Trait Split 

pub trait Split: 'static + Send {
    // Required methods
    fn as_any(&self) -> &dyn Any;
    fn execute(self: Box<Self>) -> VortexResult<SendableArrayStream>;
    fn row_count_estimate(&self) -> Estimate<u64>;
    fn byte_size_estimate(&self) -> Estimate<u64>;
}
A split represents a unit of work that can be executed to produce a stream of arrays.

Required Methods

fn as_any(&self) -> &dyn Any

Downcast the split to a concrete type.

fn execute(self: Box<Self>) -> VortexResult<SendableArrayStream>

Executes the split.

fn row_count_estimate(&self) -> Estimate<u64>

Returns an estimate of the row count for this split.

fn byte_size_estimate(&self) -> Estimate<u64>

Returns an estimate of the byte size for this split.

Implementors